# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-04-05 14:35
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ovp_users', '0023_auto_20170224_1829'),
    ]

    operations = [
        migrations.AddField(
            model_name='user',
            name='public',
            field=models.BooleanField(default=True, verbose_name='Public'),
        ),
    ]
