# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2017-01-12 21:44
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ovp_users', '0011_auto_20170111_1633'),
        ('ovp_users', '0011_auto_20170112_1417'),
    ]

    operations = [
    ]
