# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2017-01-12 14:17
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('ovp_users', '0010_user_avatar'),
    ]

    operations = [
        migrations.AlterField(
            model_name='passwordrecoverytoken',
            name='created_date',
            field=models.DateTimeField(auto_now_add=True, null=True, verbose_name='Created date'),
        ),
        migrations.AlterField(
            model_name='passwordrecoverytoken',
            name='used_date',
            field=models.DateTimeField(blank=True, default=None, null=True, verbose_name='Used date'),
        ),
        migrations.AlterField(
            model_name='user',
            name='avatar',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='avatar_user', to='ovp_uploads.UploadedImage', verbose_name='avatar'),
        ),
        migrations.AlterField(
            model_name='user',
            name='joined_date',
            field=models.DateTimeField(auto_now_add=True, null=True, verbose_name='Joined date'),
        ),
        migrations.AlterField(
            model_name='user',
            name='modified_date',
            field=models.DateTimeField(auto_now=True, null=True, verbose_name='Modified date'),
        ),
    ]
