# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-02-21 19:23
from __future__ import unicode_literals

from django.db import migrations
import uuid

def gen_uuid(apps, schema_editor):
    Model = apps.get_model('ovp_users', 'User')
    for user in Model.objects.all():
        user.uuid = uuid.uuid4()
        user.save()

class Migration(migrations.Migration):

    dependencies = [
        ('ovp_users', '0019_userprofile_public'),
    ]

    operations = [
        migrations.RunPython(gen_uuid, reverse_code=migrations.RunPython.noop),
    ]
