# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-02-20 22:17
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ovp_core', '0007_lead'),
        ('ovp_users', '0016_auto_20170216_1930'),
    ]

    operations = [
        migrations.AddField(
            model_name='userprofile',
            name='causes',
            field=models.ManyToManyField(to='ovp_core.Cause'),
        ),
    ]
