# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-04-18 16:55
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ovp_users', '0025_remove_userprofile_public'),
    ]

    operations = [
        migrations.AddField(
            model_name='userprofile',
            name='genre',
            field=models.CharField(blank=True, choices=[('male', 'Male'), ('female', 'Female')], default=None, max_length=10, null=True, verbose_name='Genre'),
        ),
    ]
